@@ -1,12 +1,8 @@
-/* ============================================================
- *
- * This file is part of the KDE project
- *
+/*
  * SPDX-FileCopyrightText: 2008-2011 Kare Sars <kare.sars@iki.fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #include "ksanebutton.h"
 
@@ -16,7 +12,24 @@ namespace KSaneIface
 KSaneButton::KSaneButton(QWidget *parent, const QString &ltext)
     : KSaneOptionWidget(parent, QString())
 {
-    m_button = new QPushButton(ltext, this);
+    initButton(ltext);
+}
+
+KSaneButton::KSaneButton(QWidget *parent, KSaneCore::Option *option)
+    : KSaneOptionWidget(parent, option)
+{
+    initButton(option->title());
+    setToolTip(option->description());
+    connect(this, &KSaneButton::clicked, option, &KSaneCore::Option::setValue);
+}
+
+KSaneButton::~KSaneButton()
+{
+}
+
+void KSaneButton::initButton(const QString &text)
+{
+    m_button = new QPushButton(text, this);
     m_layout->addWidget(m_button, 0, 1);
     m_layout->addWidget(new QWidget(this), 0, 2);
     m_layout->setColumnStretch(1, 0);
@@ -25,8 +38,6 @@ KSaneButton::KSaneButton(QWidget *parent, const QString &ltext)
     connect(m_button, &QPushButton::clicked, this, &KSaneButton::clicked);
 }
 
-KSaneButton::~KSaneButton()
-{
-}
-
 }  // NameSpace KSaneIface
+
+#include "moc_ksanebutton.cpp"
